summaryrefslogtreecommitdiff
path: root/ftpfs/ftpfs.h
diff options
context:
space:
mode:
authorSamuel Thibault <samuel.thibault@ens-lyon.org>2012-07-01 02:12:43 +0000
committerSamuel Thibault <samuel.thibault@ens-lyon.org>2012-07-01 02:12:43 +0000
commit13ea39a34766fcbecd96ab94bcdf798b08e9bb60 (patch)
tree1e1463b03838a6f36868a4dafc7e652358a51857 /ftpfs/ftpfs.h
parent1f8d504f631531c199d7c6154a0dc442d80ea4a7 (diff)
parent7e15f3d69a83a34ac62cbbee944a0bfbfa92724e (diff)
Merge branch 'master' into xkb
Conflicts: config.make.in configure.in
Diffstat (limited to 'ftpfs/ftpfs.h')
-rw-r--r--ftpfs/ftpfs.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ftpfs/ftpfs.h b/ftpfs/ftpfs.h
index d1d816d7..0eef5bde 100644
--- a/ftpfs/ftpfs.h
+++ b/ftpfs/ftpfs.h
@@ -138,7 +138,7 @@ struct netnode
/* Various parameters that can be used to change the behavior of an ftpfs. */
struct ftpfs_params
{
/* Amount of time name existance is cached. */
time_t name_timeout;
/* Amount of time stat information is cached. */
@@ -240,7 +240,7 @@ error_t ftpfs_dir_lookup (struct ftpfs_dir *dir, const char *name,
struct node **node);
/* Lookup the null name in DIR, and return a node for it in NODE. Unlike
- ftpfs_dir_lookup, this won't attempt to validate the existance of the
+ ftpfs_dir_lookup, this won't attempt to validate the existence of the
entry (to avoid opening a new connection if possible) -- that will happen
the first time the entry is refreshed. Also unlink ftpfs_dir_lookup, this
function doesn't expect DIR to be locked, and won't return *NODE locked.
@@ -138,7 +138,7 @@ struct netnode
struct ftpfs_params
{
- /* Amount of time name existance is cached. */
+ /* Amount of time name existence is cached. */
time_t name_timeout;
/* Amount of time stat information is cached. */